Monty Python's Flying Circus: Just the Words - Episode 45

# Episode Forty-five: Party Political Broadcast

'Most Awful Family in Britain'
Icelandic Honey Week
A doctor whose patients are stabbed by his nurse
Brigadier and Bishop
Appeal on behalf of extremely rich people
The man who finishes other peoples sentences
David Attenborough
The walking tree of Dahomey
The batsmen of the Kalahari
Cricket match (assegais)
BBC News (handovers)

Colour code: Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| CAPTION: 'A PARTY POLITICAL BROADCAST ON BEHALF OF THE LIBERAL PARTY'
Voice Over | There now follows a Party Political Broadcast on behalf of the Liberal Party...
| Cut to a kitchen. Mr Garibaldi is eating a packet of 'Ano-Weet'. On the back of the packet in big letters it reads 'Free Inside - The Pope + Demonstration Record'. Kevin Garibaldi is stretched out the whole length of the sofa, eating a huge plate of baked beans. His father occasionally flaps the copy of the paper he is reading at him to clear the air. The paper is called 'The Scun' and has a pin-up on the front page with big headline 'What a Scorcher! Phew! Can Resist this Miss'; at the bottom of the page in small print 'China Declares War'. The banner across top reads 'In the Scun Today "Tits and Inflation"'. Ralph Garibaldi is sitting at the table eating. At one point he stretches across the table, and his arm sticks in the butter. He tries to clean it off and knocks the sugar over. There is a large photo of Ian Smith on the wall; built around it is a plaster shrine, with flowers in front of it. Mrs Garibaldi is ironing. She irons some underclothes, then she irons a transistor radio. Dotted about the room are a flat telephone, a flat standard lamp, and a flat cat. Valerie Garibaldi is wearing a shiny red miniskirt. She has bright yellow 'beehive' hair so stiffly lacquered that it is quite a hazard to various ornaments on the mantelpiece. She is continuously making herself up in the mantelpiece mirror which is shaped like a lavatory. The other member of the family is a very fat old dog. As we see all this, the football commentary is droning throughout on the radio.
Radio Voice | Pratt... back to Pratt... Pratt again... a long ball out to Pratt... and now Pratt is on the ball, a neat little flick back inside to Pratt, who takes it nicely and sends it through on the far side to Pratt, Pratt with it but passes instead to Pratt, Pratt again, oh and well intercepted by the swarthy little number nine, Concito Maracon. This twenty-one-year-old half back, remarkably stocky for 6' 3", square shouldered, balding giant, hair flowing in the wind, bright eyed, pert, young for his age but oh so old in so many ways. For a thirty-nine.year-old you wouldn't expect such speed. Normally considered slow, he's incredibly fast as he wanders aimlessly around, sweeping up and taking the defence to the cleaners. Who would have thought, though many expected it, that this remarkable forty-five-year-old, 9' 4" dwarf of a man, who is still only seventeen in some parts of the world, would ever really be ... Oh and there was a goal there apparently ... and now it's Pratt ... back to Pratt... Pratt again... a long ball to Pratt... (crackle)
| By now mother has succeeded in flattening the radio with the iron. She folds it neatly and puts it on the pile.
Mr Garibaldi | I like this Ano-Weet, it really unclogs me.
| Ralph Garibaldi knocks a bowl onto the floor. It smashes.
Mrs Garibaldi | Oh, do be careful.
Ralph Garibaldi | Sorry, mum.
| Kevin opens another can of beans and pours them on to his plate, throwing the tin on the floor. The radio drones on.
Mr Garibaldi | I mean a lot of others say they unclog you, but I never had a single bowel movement with the 'Recto-Puffs'.
Ralph Garibaldi | Now if we ... (he knocks the cereal box off the table) Oh, sorry, mum ... Now if we lived in Rhodesia there'd be someone to mop that up for you.
Valerie Garibaldi | (turning from the mirror in mid make-up) Don't be so bleedin' stupid. If you lived in bleedin' Rhodesia, you'd be out at bleedin' fascist rallies every bleedin' day. You're a bleedin' racist, you bleedin' are.
Mr Garibaldi | Language!
Valerie Garibaldi | Well he gets on my sodding wick.
Mr Garibaldi | That's better.
| Mother is now ironing the telephone and the cat. She irons them flat and pins them on the line.
Mr Garibaldi | No, the stuff I liked was that stuff they gave us before the war, what was it - Wilkinson's Number 8 Laxative Cereal. Phew. That one went through you like a bloody Ferrari...
| The doorbell rings.
Mrs Garibaldi | Now, who's that at this time of day... (she goes out)
Mr Garibaldi | If it's the man to empty the Elsan, tell him it's in the hall.
Mrs Garibaldi | Right, dear.
Mr Garibaldi | And make sure that you hold it the right way up!
Ralph Garibaldi | Dad... ?
| A middle-aged man appears from the broom cupboard.
Strange Man | Yeah?
Ralph Garibaldi | No no, my dad...
Strange Man | Oh... (he gets back into the cupboard again)
Ralph Garibaldi | Dad? Why is Rhodesia called Rhodesia?... (he knocks the teapot on to the floor, it smashes) Oh sorry, dad.
| Cut to the doorway in the hall. A man in a dark suit, very smart and well-dressed, is doing strange kung-fu antics.
Mrs Garibaldi | No... no, really, thank you very much... no, thank you for calling, not today, thank you. Good morning.
| She shuts the door on him. As she does so Mr Garibaldi shouts out to her.
Mr Garibaldi | Who was that?
Mrs Garibaldi | (coming in again) The Liberal Party candidate, darling... oh ... what have you done now?
Ralph Garibaldi | Sorry, mum. (he is standing beside the sink which has just split in two) I was just washing up...
Mrs Garibaldi | Go and sit down!
Ralph Garibaldi | Mum? Do you know why Rhodesia's called Rhodesia?
Mr Garibaldi | Do you remember 'Go-Eazi'? They were hopeless... (Kevin opens another can of beans; dad notices in disgust and flaps his paper again) little black pellets... tasted foul and stuck inside you like flooring adhesive.
Valerie Garibaldi | (she has finally finished her startling make-up) Right, I'm off.
Mrs Garibaldi | When are you coming back tonight?
Valerie Garibaldi | 3 a.m.
Mrs Garibaldi | I think it's disgusting... you a Member of Parliament.
Mr Garibaldi | I heard you in the hall last night, snogging away.
Valerie Garibaldi | I wasn't snogging!
Mr Garibaldi | Sounded like snogging to me. I could hear his great wet slobbering lips going at yer ... and his hand going up yer...
Mrs Garibaldi | Dad!
Strange Man | (coming out of the cupboard) Yes.
Mrs Garibaldi | No ... not you.
Strange Man | Oh! (he goes back in again)
Mrs Garibaldi | Just mind your language...
| Ralph knock a leg off the table. It collapses entirely.
Ralph Garibaldi | Oh, sorry, mum.
Kevin Garibaldi | (too fat and flatulent to get up) I've run out of beans!
Valerie Garibaldi | We was talking, we was not snogging.
Mr Garibaldi | Talking about snogging, I'll bet...
| The phone rings. Mrs Garibaldi answers it.
Valerie Garibaldi | If you must know, we was talking about Council re-housing.
Mrs Garibaldi | (on the phone) Would it mean going to live in Hollywood?
Kevin Garibaldi | (desperate but unable to move) I run out of beans!
Mr Garibaldi | Where to re-house his right hand, that's what he was interested in!
Mrs Garibaldi | And has Faye Dunaway definitely said yes?
Valerie Garibaldi | He is the Chairman of the Housing sub-committee.
| (The bell rings.)
Mr Garibaldi | Snogging sub-committee, more like...
Mrs Garibaldi | Ralph, do answer that door will you!
Kevin Garibaldi | Beans!!
Mrs Garibaldi | Shut up!!
Ralph Garibaldi | Yea, mum.
Mr Garibaldi | (shouting to Ralph) If it's the man from the Probbo-Rib, tell him it's in the bed.
| Ralph gets up. As he goes he knocks the leg off the old-fashioned gas cooker. It falls to one side bringing down shelves next to it, plates, crockery and a section of the wall revealing the hallway the other side.
Ralph Garibaldi | Sorry, mum.
Kevin Garibaldi | (roaring) Beans! Beans!
Mrs Garibaldi | Shut up!
| A man in a Tarzan outfit, except with a postman's hat and a little mailbag, swings in on a liana shouting a jungle yell.
Postman | Postman-a-a-n!!
| A gong sounds. They all stop acting. Cut to stock film of ladies applauding. Pull out from this stock film to see that it is on a screen in a presentation studio. A glittery compère is also applauding sycophantically at his desk, about which is the glittery slogan 'Most Awful Family in Britain, 1974. Sponsored by Heart Attacko Margarine'.
Presenter | A very good try there, by the Garibaldi family of Droitwich in Worcestershire. Professor...
| Pull out further to pick up a panel of three distinguished rather academic looking people.
Professor | Well, I can't make up my mind about this family... I don't think there was the sustained awfulness that we really need. I mean, the father was appalling...
| Two other members of the panel nod vigorous agreement.
Lady Organs | Appalling... yes ....
Professor | He was dirty, smelly and distasteful ... and I liked him very much ... but...
Presenter | Lady Organs?
Lady Organs | Well ... they were an unpleasant family certainly, but I don't think we had enough of the really gross awfulness that we're looking for...
Presenter | Well, harsh words there for the Garibaldi family of Droitwich in Worcestershire, at present holders of the East Midlands Most Awful Family Award - Lower Middle-Class Section but unable today to score more than fifteen on our disgustometer. Well with the scores all in from the judges, the Garibaldis are number three ... and a surprise number two ... the Fanshaw-Chumleighs of Berkshire... (he turns to the screen)
| A very elegant breakfast table in beautifully tasteful surroundings. Four upper-class folk - two woman (Michael and Graham) and two men (Eric and Terry J) - are talking most incredibly loudly at each other, with quite appalling accents. An appalling din altogether. They talk just about at the same time as each other.
First Person | What a super meal.
Second Person | Absolutely super. Pat and Max are coming down from Eton to help daddy count money.
Third Person | How absolutely super.
Fourth Person | My man at Poirer's says I could have my whole body lifted for £5,500
First Person | How super... (etc.)
| Cut back to the panel nodding thoughfully.
Presenter | Well, some of the wonderful behaviour that made the Fanshaw-Chumleighs the second Most Awful Family in Britain 1974. But the winners, by a clear ten point margin, are once again the awful Jodrell family of Durham. Unfortunately, we're not allowed to show you some of the performance that won them an award, but I assure you it was of the very highest standard, was it not, Lady Organs?
Lady Organs | Oh, yes, superb ... Mr Jodrell - you know, the old grandfather, who licks the ...
Presenter | (hurriedly) Yes, yes...
Lady Organs | He's superb. His gobbing is consistent and accurate. His son is a dirty foul little creature, and those frightful scabs which Mrs Jodrell licks off the cat are...
Presenter | (during this speech we cut to the same image on a TV screen) Well, thank you very much, Lady Organs ... and from all of us all, well done to the Jodrells ... and to all of you, not forgetting those of you who may be halfway in between, without whom, of course, and not forgetting who made it all possible, when, and we'll be back, until then and so it's goodnight from me and here's wishing you a safe journey home, thank you for watching this show, don't forget it was all great fun, I've enjoyed it, and I hope you watching at home have enjoyed it too.
| He is switched off, and fades into a dot. Pull back to reveal that the TV which has just been switched off is in a dirty old sitting room in which all the characters are really unpleaant pepperpots. They are dressed more or less identically, except that son has a school cap and a blazer over his pepperpot gear. He has a satchel and National Health glasses. The father has moustache and glasses and a Fair-Isle jersey.
Mother | The Jodrells win every bloody year... makes you vomit ... dad?
Dad | Yes?
Mother | Get your stinking feet off the bread.
Dad | I'm only wiping the cat's do's off.
Son | Mum?
Mother | Shut yet face, Douglas.
Son | I wanted some corn-plasters.
Mother | Shut up and eat what you got.
| A cat set into the wall, i.e. a glove puppet, screeches as if someone had pulled its tail outside.
Dad | Some fat bastard at the door! (to the cat) Shut up! (she slaps it; it expires)
| She takes a couple of milk bottles out. Standing on the doorstep is a man with a Nordic accent in female national costume. He has a tray labeled 'Icelandic Honey Week'
Man | A strong hive of bees contains approximately 75,000 bees. Each honey bee must make 154 trips to collect one teaspoon of honey. Hello, sir.
Dad | What do you want?
Man | Would you like to buy some of our honey, sir?
Mother | What you doing in here?
Man | Which would you like, the Californian Orange Blossom, the Mexican, the New Zealand, or the Scottish Heather?
Mother | He can't eat honey. It makes him go plop plops.
Man | Come on, please try some.
Dad | All right I'll have some Icelandic Honey.
Man | No, there is no such thing.
Dad | You mean you don't make any honey at all?
Man | No, no, we must import it all. Every bally drop. We are a gloomy people. It's so crikey cold and dark up there, and only fish to eat. Fish and imported honey. Oh strewth!
Mother | Well why do you have a week?
Man | Listen Buster! In Reykyavik it is dark for eight months of the year, and it's cold enough to freeze your wrists off and there's only golly fish to eat. Administrative errors are bound to occur in enormous quantities. Look at this - it's all a mistake. It's a real pain in the sphincter! Icelandic Honey Week? My Life!
Mother | Well why do you come in here trying to flog the stuff, then?
Man | Listen Cowboy. I got a job to do. It's a stupid, pointless job but at least it keeps me away from Iceland, all right? The leg of the worker bee has...
| They slam the door on him. Someone rather like Jeremy Thorpe looks round the door and waves as they do so. Animated titles. Then cut to a drawing of Indians attacking a fort. Music: 'The Big Country' theme.
Voice Over | (and superimposed roller caption:) 'IN THE SPRING OF 1863 THE COMANCHES RALLIED UNDER THEIR WARRIOR LEADER CONCHITO IN A FINAL DESPERATE ATTEMPT TO DRIVE THE WHITE MAN FROM THE RICH HUNTING LANDS OF THEIR ANCESTORS. THE US CAVALRY WERE DRAWN UP AT FORT WORTH, AND THE SCENE WAS SET FOR THE FINAL ALL OUT ONSLAUGHT THAT COULD SET THE NEW TERRITORIES ABLAZE'
| Cut to a doctor's surgery. It has a wall shrine with a photo of Christiaan Barnard with flowers and candles in front of it. The doctor is talking to an embarrassed-looking man.
Doctor | Well, Mr Cotton, you have what we in the medical profession call a naughty complaint. My advice to you is to put this paper bag over your head - it has little holes there for your eyes, you see - and to ring this bell, and to take this card along to your hospital. (he hands him card three feet long which reads 'For Special Treatment') And I shall inform all your relatives and friends and anyone else I bump into. OK... cash, wasn't it? (the man hands him over wad of fivers) Thank you very much. Get out. (the man gets up to go) Dirty little man. (he picks up big text book entitled 'Medical Practice' and flicks through the pages) Hmm.,. hmm ... Hippocratic oath ... it's not in there ... jolly good. Very useful. Next!
| An out-of-vision scream. A man staggers in clutching his bleeding stomach. Lots of blood pours out of him throughout the scene.
Doctor | Ah, yes you must be Mr Williams.
Williams | (obviously fatally wounded) Y... yes...
Doctor | Well, do take a seat. What seems to be the trouble?
Williams | I've... I've just been stabbed by your nurse...
Doctor | Oh dear.... well I'd probably better have a look at you then. Could you fill in this form first? (he hands him a form)
Williams | She just stabbed me...
Doctor | Yes. She's an unpredictable sort. Look, you seem to be bleeding rather badly. I think you'd better hurry up and fill in that form.
Williams | Ahhh ... couldn't ... I ... do ... it ... later, doctor!
Doctor | No, no. You'd have bled to death by then. Can you hold a pen?
Williams | I'll try.
| With great effort he releases one of his hands from his bleeding stomach.
Doctor | Yes, it's a hell of a nuisance all this damn paperwork, really it is... (he gets up and strolls around fairly unconcerned) it's a real nightmare, this damned paperwork. It really is a hell of a nuisance. Something ought to be done about it.
Williams | Do I have to answer all the questions, doctor?
Doctor | No, no, no, just fill in as many as you can - no need to go into too much detail. I don't know why we bother with it all, really, it's such a nuisance. Well let's see how you've done, then... (Williams half collapses) Oh dear oh dear... that's not very good, is it. Look, surely you knew number four!
Williams | No ... I didn't...
Doctor | It's from 'The Merchant of Venice' - even I know that!
Williams | (bleeding profusely) It's going on the carpet, doctor.
Doctor | Oh don't worry about that! Look at this - number six - the Treaty of Versailles, Didn't you know that? Oh, my God.
Williams | Ahgg... aghhh.
Doctor | And number nine - Emerson Fittipaldi! (gives Williams a look) Virginia Wade? You must be mad!
| The nurse enters with a smoking revolver.
Nurse | Oh doctor, I've just shot another patient. I don't think there's any point in your seeing him.
Doctor | You didn't kill him, did you?
Nurse | 'Fraid so.
Doctor | You mustn't kill them, nurse.
Nurse | Oh, I'm sorry doctor. It was just on the spur of the moment. Rather silly really.
| She exits, taking a sword from the wall. Through the next bit of the scene we hear screams off.
Williams | I'm sorry about the carpet, doctor.
Doctor | Mr Williams, I'm afraid I can't give you any marks, so I won't be able to recommend you for hospital. Tell you what - I'll stop the bleeding - but strictly speaking I shouldn't even do that on marks like these...
| The nurse enters covered in blood.
Nurse | There are no more patients now, doctor.
Doctor | Oh well, let's go and have lunch, then.
Nurse | What about... er... (she points to Williams who is lying on the floor gurgling by this time)
Doctor | Ah yes - look, Mr Williams we're just popping out for a bite of lunch while we've got a spare moment, you know. Look, have another bash at the form... and if at least you can answer the question on history right, then we may be able to give you some morphine or something like that, OK?
Williams | Thank you, doctor, thank you.
| Cut to a large country house sitting more, dominated by large grinning portrait of Jeremy Thorpe. A bishop is sitting at a desk, typing. A brigadier in full military uniform just to below the chest, then a patch of bare midriff, with belly button showing, then a lavender tutu, incredibly hairy leg, thick army socks and high heels, is dictating.
Brigadier | Dear Sir, I wish to protest in the strongest possible terms. Yours sincerely, Brigadier N. F. Marwood-Git (retired). Read that back, will you, Brian.
Bishop | And when he had built up Cedron, he sent Horsemen there, and an host of footmen to the end that issuing out they might make outroads upon the ways of Judea, as the King commanded them...
Brigadier | Good! Pop it in an envelope and bung it off! It's no good bottling these things up, Brian. If you feel them you must say them or you'll just go mad...
Bishop | Oh yes indeed ... as the book of Maccabee said ... Ye as the flea is like unto an oxen, so is the privet hedge liken unto a botanist black in thy sight, O Lord!
Brigadier | Quite... Look why don't you just nip out for lunch, Brian...
Bishop | Yea ... as Raymond Chandler said, it was one of those days when Los Angeles felt like a rock-hard fig.
Brigadier | Brian, let's stop this pretending, shall we.
Bishop | Oh... ye... as Dirk Bogarde said in his autobiography...
Brigadier | Brian... let's stop all this futile pretence... I've... I've always been moderately fond of you...
Bishop | Well to be quite frank, Brigadier ... one can't walk so closely with a chap like you for... for so long without... feeling something deep down inside, even if it isn't anything... anything ... very much.
Brigadier | Well, splendid... Brian... er... well I don't suppose there's much we can do, really.
Bishop | Not on television ... no...
Brigadier | No... they ... they are a lot more permissive these days than they used to be...
Bishop | Ah yes... but not with this sort of thing...
Brigadier | No ... I suppose they've ... got to draw the line somewhere...
Bishop | Yes...
Brigadier | Well take a letter, Brian. Dear Sir, I wish to protest...
| Cut to an animation sketch.
Voice Over | (and CAPTION:) 'THERE NOW FOLLOWS AN APPEAL ON BEHALF OF EXTREMELY RICH PEOPLE WHO HAVE ABSOLUTELY NOTHING WRONG WITH THEM'
Sir Pratt | (at a large leather-topped desk with an elaborate table lamp) Hello. I'd like to talk to you tonight about a minority group of people who have no mental or physical handicaps and, who, through no fault of their own, have never been deprived, and consequently are forced to live in conditions of extreme luxury. This often ignored minority, is very rarely brought to the attention of the general public. The average man in the street scarcely gives a second thought to these extremely well-off people. He, quite simply, fails to appreciate the pressures vast quantities of money just do not bring. Have you at home, ever had to cope with this problem... (cut to a rich young yachting type surrounded by girls in bikinis) or this... (cut to a rich woman loading her chauffeur with all kinds of expensive parcels) or even this... (cut to a still of Centre Point) I know it's only human to say, 'Oh this will never happen to me', and of course, it won't. I'm asking you, please, please, send no contributions, however large, to me.
| We see the last bit on a TV in Mrs What- a- long- name- this- is- hardly- worth- typing- but- never- mind- it- doesn't- come- up- again's living- room. Ding-dong of doorbell. A cupboard door opens, and the middle-aged man we saw in first scene comes out. He has no iguana on his shoulder.
Mrs Long Name | All right, I'll go.
TV Voice | There now follows a Party Political Broadcast on behalf of the Liberal Par...
| She turns it off. The TV set just folds up as if empty and collapses on to the floor. Dust rises. She goes into the hallway to the front door (singing 'Anything Goes' by the other Cole Porter to herself) and opens it. A man with a briefcase stands there.
Mr Vernon | Hello, madam... (comes in)
Mrs Long Name | Ah hello... you must have come about...
Mr Vernon | Finishing the sentences, yes.
Mrs Long Name | Oh... well... perhaps you'd like to...
Mr Vernon | Come through this way... certainly... (they go through into the sitting room) Oh, nice place you've got here.
Mrs Long Name | Yes ... well ... er... we...
Mr Vernon | Like it?
Mrs Long Name | Yes ... yes we certainly...
Mr Vernon | Do... Good! Now then... when did you first start...
Mrs Long Name | ... finding it difficult to...
Mr Vernon | Finish sentences... yes.
Mrs Long Name | Well it's not me, it's my...
Mr Vernon | Husband?
Mrs Long Name | Yes. He...
Mr Vernon | Never lets you finish what you've started.
Mrs Long Name | Quite. I'm beginning to feel...
Mr Vernon | That you'll never finish a sentence again as long as you live.
Mrs Long Name | Exact...
Mr Vernon | ly. It must be awful.
Mrs Long Name | It's driving me...
Mr Vernon | To drink?
Mrs Long Name | No, rou...
Mr Vernon | nd the be...
Mrs Long Name | en...
Mr Vernon | d...
Mrs Long Name | Yes...
Mr Vernon | May I...
Mrs Long Name | Take a seat...
Mr Vernon | Thank you. (he sits) You see, our method is to reassure the patient by recreating normal... er...
Mrs Long Name | Conditions?
Mr Vernon | Yes. Then we try to get them in a position where they suddenly find that they're completing other people's sentences...
Mrs Long Name | (with self-wonder) Themselves!
Mr Vernon | Spot on Mrs...
Mrs Long Name | (hesitantly) Smith?
Mr Vernon | Good! Well, try not to overdo it to...
Mrs Long Name | (with growing confidence) Begin with... ?
Mr Vernon | Good. Just keep it to one or two...
Mrs Long Name | (faster) Words ....
Mr Vernon | To start off with, otherwise you may find that you're...
Mrs Long Name | Taking on too long a sentence and getting completely ... er...
Mr Vernon | Stuck. Good. Yes. Well that's about it...
Mrs Long Name | (completely confident now) for now, so...
Mr Vernon | Thanks very much for calling.
Mrs Long Name | Not at all.
Mr Vernon | And, er...
Mrs Long Name | Just like to say
Mr Vernon | Thank you very much for coming along.
Mrs Long Name | Not at all
Mr Vernon | And good...
Mrs Long Name | Bye, Mr...
Mr Vernon | Vernon.
| Mrs Long Name leaves. Mr Vernon shuts the door. A girl's voice comes from sitting room.
Girl's Voice | Carl?
Mr Vernon | Yes, dear?
Girl's Voice | I've just had another baby.
Mr Vernon | Oh, no! How many's that now?
Girl's Voice | Twelve since lunch... Oh! There's another one!
| Cut to exterior of Mrs Long Name's house. She comes out and sets off purposefully up the road, passing four pepperpot nannies digging up the road. They are wearing the usual slippers, paisley dresses and knotted handkerchief. One wears a helmet. One works a pneumatic drill. She is stripped to the waist wearing a big pink bra. Behind, heroic shots of Mrs Long Name walking out of town, through suburbs, into neat country, then into wilder country. She finally stops in close up, and looks up with inspiration in her eyes. Cut to a linkman standing before Stonehenge.
Linkman | This is Stonehenge ... and it's from here we go to Africa.
| Jeremy Thorpe appears at the edge of shot and waves. Cut to an as overgrown, jungleoid location as Torquay can provide. A very big thick tree in the foreground. David Attenborough pushes through jungle towards camera. He has damp sweat patches under his arms which grow perceptibly during the scene. He has two African guides in the background both with saxophones round their neck.
Attenborough | (slapping the side of a tree) Well here it is at last ... the goal of our quest. After six months and three days we've caught up with the legendary walking tree of Dahomey, Quercus Nicholas Parsonus, resting here for a moment, on its long journey south. It's almost incredible isn't it, to think that this huge tree has walked over two thousand miles across this inhospitable terrain to stop here, maybe just to take in water before the two thousand miles on to Cape Town, where it lives. It's almost unimaginable, I find - the thought of this mighty tree strolling through Nigeria, perhaps swaggering a little as it crosses the border into Zaire, hopping through the tropical rain forests, trying to find a quiet grove where it could jump around on its own, sprinting up to Zambia for the afternoon, then nipping back ... (a native whispers in his ear) Oh, super ... well, I've just been told that this is not in fact the legendary walking tree of Dahomey, this is one of Africa's many stationary trees, Arborus Barnbet Gaseoignus. In fact we've just missed the walking tree... it left here at eight o'clock this morning... was heading off in that direction... so we'll see if we can go and catch it up. Come on boys.
| They move off. At this point we notice that there are two other saxophone-wearing natives, a trumpeter, a trombonist, a double bassist, a guitarist, and finally a man with a drum kit tied to his back. Mix through to them on the move in another pan of the jungle. Sweat is now spraying out from under Attenborough's armpits as if from a watering can.
Attenborough | Well, we're still keeping up with it, but it's setting a furious pace. Early this morning we thought we'd spotted it, but it turned out to be an Angolan sauntering tree, Amazellus Robin Ray, out walking with a Gambian Sidling Bush... (Jeremy Thorpe leans in the background and waves to camera) So on we go ... it's going to be difficult - the walking tree can achieve speeds of up to fifty miles an hour, especially when it's in a hurry. (Rupert the bearer points excitedly) Super! Well, Rupert has spotted something ... this could be it... a walking tree on the move ... (they move off, by this time waterspray is gushing out from all over his chest) But, what Rupert had in fact discovered was something very different...
| He stops him, they kneel down. Cut to their eyeline. In the distance, amongst low bushes and thick undergrowth, six Africans dressed immaculately in cricket gear having a game of cricket. Cut to Attenborough, Rupert and one other bearer watching. Attenborough is looking down at something he is holding. The other two are gazing wide-eyed at the cricketers.
Attenborough | The Turkish Little Rude Plant. (he holds up, carefully and wondrously, a plant which has green outer leaves splayed back to reveal a small, accurately sculpted bum) This remarkably smutty piece of flora was used by the Turks to ram up each other's ... (Rupert nudges him and points excitedly at the batsmen) Ah no! In fact it was something even more interesting... (Attenborough points, apparently at the batsmen, but he has clearly got it wrong again) Yes, there it was, over the other side of the clearing, the legendary Puking Tree of Mozambique... (Rupert nudges him again)
| Cut to an animated professor.
Voice | No, what they had come across was a tribe lost to man since time immemorial... the legendary Batsmen of the Kalahari... (cut to a shot of natives playing cricket)
Voice Over | Primitive customs still survive here as if the march of time had passed them by. But for all the mumbo-jumbo and superstition, the Batsmen of the Kalahari are formidable fighters, as we can see on this rare footage of them in action against Warwickshire.
| Cut to a big county ground pavilion in mid-shot. We zoom in on the commentator on a balcony.
Commentator | Warwickshire had dismissed the Kalahari Batsmen for 140, and then it was their turn to face this extraordinary Kalahari attack. Pratt was the first to go, but Pratt and Pratt put on a second wicket stand of nought, which was broken by Odinga in his most hostile mood.
| A compilation of the day's play. Natives in normal cricket gear. Pratt at crease as per usual cricket coverage. Cut to a low shot of the bowler thundering up towards the wicket. Cut away to the batsman preparing to take the shot. Cut back to the bowler. As he reaches the crease he produces a spear and raises it to shoulder height and hurls it. Cut to batsman who is hit full in the stomach. His bat dislodges the bails. There is a 'howzat' from all the native fielders. He makes an annoyed gesture as if he were Colin Cowdrey caught clean bowled, and sinks to the ground.
| CAPTION: 'B. RATT'
Voice Over | Thats B. Pratt, hit wicket - 0. But Pratt and Z. Pratt dug in and took the score to a half... (cut to the new batting partnership; B. Pratt's body is still on the ground) before Z. Pratt ran away. (Z. Pratt reaching the pavilion, running with a hail of spears and arrows coming after him) But out came M.J.K. Pratt... (cut to M.J.K. Pratt coming out pulling on gloves etc.) to play a real captain's innings. (he reaches the crease and takes guard, the bowler bowls) He'd taken his own score up to nought when he mistimed a shot of Bowanga and was lbw. (a huge spear sticks right through the lower part of his leg; they appeal and he turns and limps manfully off)
| CAPTION: 'M.J.K. PRATT'
Voice Over | Typical of Umbonga's hostile opening spell was his dismissal of V.E. Pratt, who offered no resistance to this delivery... (cut to native bowler bowling a machete; it hits the ground and does a leg spin up, slicing off the batsman's head as he waves his bat) ... and he was caught behind.
| The batsman's severed head lands in the wicket keeper's gloves. He throws it in the air with a flourish.
| CAPTION: 'V.E. PRATT'
| Jeremy Thorpe appears and waves. Cut to the presenter from 'World' s Most Awful Family 1974'.
Presenter | But by lunch the situation had changed dramatically.
Voice Over | (and CAPTION:) 'C.U. PRATT KILLED OUTRIGHT, BOWLED ODINGA - 0. P.B.T.R. PRATT LEGS OFF BEFORE WICKET, BOWLED ODINGA - 0. B.B.C.T.V. PRATT ASSEGAI UP JACKSEY, BOWLED UNBOKO - 0. Z. PRATT MACHETE BEFORE WICKET, 'BOWLED UMBONGA - 0. M.J.K. PRATT STUMP THROUGH HEAD, BOWLED UMBONGA - 0. V.E. PRATT RAN AWAY - 0. P.D.A. PRATT RETIRED HURT - 0. W.G. PRATT RETIRED VERY HURT - 0. PRATT DIED OF FRIGHT, BOWLED ODINGA - 0. Y.E.T.A.N.O.T.H.E.R. PRATT NOT OUT BUT DREADFULLY HURT- 139.'
| Cut back to the presenter. Behind him the 'Worlds Most Awful Family' sign is crossed out and replaced with 'Sport'.
Presenter | And so with the tension colossal as we come up to the last ball ... that's all from us.
| Roll credits on black background. The first part of the signature tune is played very hesitantly on guitar.
| PARTY POLITICAL BROADCAST ON BEHALF OF THE LIBERAL PARTY WAS CONCEIVED, WRITTEN AND PERFORMED BY J. THORPE (AGE 2) C. SMITH (AGE 1 1/2) L. BYERS (AGE O) UNSUCCESSFUL CANDIDATES GRAHAM CHAPMAN LEICESTER NORTH (LOST DEPOSIT) TERRY GILLIAM MINNEAPOLIS NORTH (LOST DEPOSIT TWICE) ERIC IDLE SOUTH SHIELDS NORTH (LOST DEPOSIT BUT FOUND AN OLD ONE WHICH HE COULD USE) TERRY JONES COLWYN BAY NORTH (SMALL DEPOSIT ON HIS TROUSERS) MICHAEL PALIN SHEFFIELD NORTH (LOST HIS TROUSERS) MORE UNSUCCESSFUL CANDIDATES CAROL CLEVELAND (LIBERAL) BOB E. RAYMOND (VERY LIBERAL) PETER BRETT (EXTREMELY LIBERAL AND RATHER RUDE) EVEN MORE UNSUCCESSFUL CANDIDATES DOUGLAS ADAMS SILLY WORD (NORTH) NEIL INNES SILLY WORDS AND MUSIC (NORTH) (COPYRIGHT 1984 THORPE-O-HITS LTD) MAKE-UP AND HAIRDRESSING JO GRIMOND MORE MAKE-UP MAGGIE WESTON EVEN MORE MAKE-UP ANDREW ROSE (COSTUMES NORTH) MUCH MORE MAKE-UP STAN SPEEL (FILM CAMERAMAN NORTH) MAKE-UP AND SOUND RECORDING RON (NORTH) BLIGHT ROSTRUM CAMERA WITH MAKE-UP PETER WILLIS FILM EDITOR AND NOT MAKE-UP BOB DEARBERG NOT FILM EDITOR NOT MAKE-UP BUT DUBBING MIXER ROD GUEST LIGHTING, MAKE-UP AND PRICES AND INCOMES POLICY JIMMY PURDIE VISUAL EFFECTS AND MR THORPE'S WIGS JOHN HORTON PRODUCTION ASSISTANT BRIAN JONES (MAKE-UP NORTH) DESIGNER (NORTH) VALERIE WARRENDER (FAR TOO LIBERAL) PRODUCED BY MR LLOYD GEORGE (WHO KNEW IAN MACNAUGHTON'S FATHER) A BBC-LIBERAL-TV-PARTY PRODUCTION (NORTH)
| Nine O'clock News intro in the newsroom behind. Behind the newsreader several men including Jeremy Thorpe are drinking and celebrating. A woman is dancing on the table.
Newsreader | Good evening. Over 400,000 million pounds were wiped off the value of shares this afternoon, when someone in the Stock Exchange coughed. Sport: capital punishment is to be re-introduced in the first and second division. Any player found tackling from behind or controlling the ball with the lower part of the arm will be hanged. But the electric chair remains the standard punishment for threatening the goalie. Referee's chairman, Len Goebbels said 'at last the referee has been given teeth'. Finally, politics: the latest opinion poll published today shows Labour ahead with 40%, the AA second with 38% and not surprisingly Kentucky Fried Chicken running the Liberals a very close third. And now back to me. Hello. And now it's time to go over to Hugh Delaney in Paignton.
| Cut to the linkman on the pier at Paignton. A smallish crowd is gathered behind him including Jerermy Thorpe who waves at the camera from the back.
Linkman | Hello and welcome to Paignton, because it's from Paignton that we take you straight back to the studio.
| Cut to a man in swimming trunks and a snorkel pushed back on his head standing in the studio holding a stuffed polecat on a pole.
Man | Hello. And it's from here we go over there.
| Cut to the 'Most Awful Family' presenter.
Presenter | Well we're already here so let's go over there.
| Cut back to the newsreader.
Newsreader | Welcome back. And now it's time for part eight of our series about the life and work of Ursula Hifier, the Surrey housewife who revolutionized British beekeeping in the nineteen-thirties.
Voice Over | (and CAPTION:) 'THAT WAS A PARTY POLITICAL BROADCAST ON BEHALF OF THE LIBERAL PARTY'
| His voice breaks up with giggles. Fade to blackout. The end.